Token

Struct Token 

pub struct Token<'scope, 'spawner, O> { /* private fields */ }
Scope Token

Implementations

Source

impl<'scope, 'spawner, O> Token<'scope, 'spawner, O>

pub unsafe fn used<T: 'scope>(&self, used: T) -> Spawner<'scope, 'spawner, T, O>

Use references

Specify the reference to use when spawning the task.

Safety

This is not sound.

the user must ensure that scope task is legally consumed, and assume that the runtime handles the task correctly.